#|

 This is a dialog to drill and counterbore a hole.  

 08-Dec-1999 Added table for standard sizes.

 13-Dec-1999 Added multi-point capability

 30-Dec-1999 Enhanced feedback 

 26-Jun-2000 Changed pick location behavior to match drill hole

|#

;; Last modified     : 26-Jun-2000
;; Category          : Machining
;; Author            : Bruce Fisher (bfisher@lhcarbide.com)
;; Company           : L.H. Carbide Corporation
;; Macro Purpose     : Drill and counterbore a hole
;; Filename          : hl_cbore.lsp
;; Revision          : 2.30
;; SD Revision	   : 7.11,7.51
;; Platform          : Windows NT 4.0
;; Video Mode        :  Native
;; Monitor Resolution:  1280x1024

(in-package :LHC)
(use-package :OLI)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; calls functions "bore_hl" and "pch_hole"

(sd-create-logical-table 
     "Std_cbore-table"
     :columns     '(:Shcs_size  :Thru_dia   :Bore_dia   :B_Dpth)
     :columnNames '("SHCS size" "Thru Dia" "Bore Dia"  "Cbore Dpth" )
     :types       '(:string        :length    :length     :length )
     :units       '(   nil         :inch      :inch       :inch   )
     :contents  '((" #0"    (.0730 :inch) (.1250 :inch) (.0900 :inch))
                  (" #1"    (.0890 :inch) (.1563 :inch) (.1000 :inch))
                  (" #2"    (.1065 :inch) (.1875 :inch) (.1200 :inch))
                  (" #3"    (.1200 :inch) (.2188 :inch) (.1300 :inch))
                  (" #4"    (.1360 :inch) (.2188 :inch) (.1400 :inch))
                  (" #5"    (.1540 :inch) (.2500 :inch) (.1500 :inch))
                  (" #6"    (.1695 :inch) (.2812 :inch) (.1700 :inch))
                  (" #8"    (.1935 :inch) (.3125 :inch) (.2000 :inch))
                  (" #10"   (.2210 :inch) (.3750 :inch) (.2200 :inch))
                  (" 1/4"   (.2810 :inch) (.4375 :inch) (.2800 :inch))
                  (" 5/16"  (.3437 :inch) (.5312 :inch) (.3400 :inch))
                  (" 3/8"   (.4062 :inch) (.6250 :inch) (.4000 :inch))
                  (" 7/16"  (.4687 :inch) (.7188 :inch) (.4700 :inch))
                  (" 1/2"   (.5312 :inch) (.8125 :inch) (.5300 :inch))
                  (" 5/8"   (.6562 :inch) (1.0000 :inch) (.6500 :inch))
                  (" 3/4"   (.7812 :inch) (1.1875 :inch) (.7800 :inch))
                  (" 7/8"   (.9062 :inch) (1.3750 :inch) (.9000 :inch))
                  (" 1"     (1.0312 :inch) (1.6250 :inch) (1.0300 :inch))
                  (" 1 1/4" (1.3125 :inch) (2.0000 :inch) (1.2800 :inch))
                  (" 1 1/2" (1.5625 :inch) (2.3750 :inch) (1.5300 :inch))
                )
 )

(sd-create-display-table
     "Std_cbore-table"
     :tableTitle "Std CBore Sizes"
     :logicalTable  "Std_cbore-table"
     :columns     '(:Shcs_size  :Thru_dia   :Bore_dia   :B_Dpth)
     :applyColumns          '(:Thru_dia :Bore_dia :B_Dpth)
     :displayHeight 320
     :filterStatusLine       nil
     :selectionMode          :single-row 
     :applyAction            :default-tokens
)


(defun lhc-show-cbore-table ()
  (sd-show-display-table "Std_cbore-table"
                              :position '("TOP-MENU-TOOLBOX-TB"
                                                       :bottomleft  330 150)
  )
)

(defun lhc-hide-cbore-table ()
  (sd-hide-display-table "Std_cbore-table" :ignorePin t))

(sd-defdialog 'lhc_hl_cbore
  :dialog-title " C'Bore Hole "
  :variables
  '((POINT_LIST)
   (A_PART 
            :value-type :part-incl-new
	      :modifies :contents 
	      :title "Part"
	      :prompt-text "Identify part to bore.")
    (A_WP   
            :value-type :wp 
	      :title "Workplane"
	      :prompt-text "Identify workplane.")
    (PNT_1 
            :value-type :point-3d-pick
            :title "Location"
            :toggle-type :invisible
            :prompt-text "Pick a point or press Back"
            :after-input (progn
                (push-point pnt_1)
                (sd-call-cmds (c_point pnt_1)))
    )  
    (TMP_NUM
              :initial-value 0)
    (NM_HLS
            :title "No. Hls"
            :value-type :display-only
            :initial-value 0
            :display-units :length) 


    (THRU_DIA 
              :value-type :positive-number
              :title "Thru Dia."
              :show-input-tool (lhc-show-cbore-table)
              :hide-input-tool (lhc-hide-cbore-table)  
              :prompt-text "Enter thru diameter"
              :after-input
                (setq Table_values (sd-read-logical-table-row
                                 "Std_cbore-table"
                                 :pList `(:Thru_dia, thru_dia)
                                 :units  :internal
                             )
                bore_dia   (getf Table_values :bore_dia)
                b_dpth     (getf Table_values :b_dpth)
                 )
    )
    (BORE_DIA 
              :value-type :positive-number
              :title "C'Bore Dia."
              :prompt-text "Enter c'bore diameter")
    (B_DPTH 
            :value-type :positive-number
            :title "C'Bore Depth"
            :prompt-text "Enter C'bore depth")
    (BACK :push-action (pop-point)))

  :local-functions
    '((PUSH-POINT (a-new-point)
         (push a-new-point point_list)
         (setq tmp_num (+ tmp_num 1))
         (setq nm_hls (* tmp_num 25.4))
         (push a-new-point point_list)
     )
      (POP-POINT ()
         (pop point_list)
         (setq tmp_num (- tmp_num 1))
         (setq nm_hls (* tmp_num 25.4))
         (unless point_list
           (sd-set-variable-status 'back :enable nil)))

     (MAIN-ACTION ()
       (dolist (pnt_1 point_list)
       (punch_hl a_part pnt_1 thru_dia))
       (dolist (pnt_1 point_list)
       (bore_hl a_part pnt_1 b_dpth bore_dia))
    ))
  :prompt-variable 'pnt_1
  :ok-action
  '(main-action))
