#|

This is a dialog to drill a hole with limited prompts.  The drill 
point is calculated as 118 degrees included angle, which is standard.

Re-written to call the function mk_drill which does the actual work.

Added table for standard sizes.

Added option to drill flat bottom hole which really just combines the
bore program with the drill program, saving code and making everyone happy.

Added option to punch the hole thru, making everyone happier still.

13-Dec-1999  Added code to allow multiple locations and counter for feedback

14-Dec-1999  Places a construction center point at selected point location.  This
             has the effect of highlighting the selection, aiding user feedback.
             It would be nice to have cleanup code that would delete the point
             when the user backs up.

             Moved the table definition to a form file and loaded separately
|#

;; Last modified  : 14-Dec-1999
;; Category       : Machining
;; Author         : Bruce Fisher (bfisher@lhcarbide.com)
;; Company        : L.H. Carbide Corporation
;; Macro Purpose  : Drill standard hole with standard drill point
;; Filename       : pch_dr_br.lsp
;; Macro Revision	: 2.41
;; SD Revision	: 7.11,7.51
;; Platform       : Windows NT 4.0
;; Video Mode        :  Native
;; Monitor Resolution:  1280x1024

(in-package :LHC)
(use-package :OLI)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; Change pathname below as needed
(load "std_dr_size.lst")

(sd-create-logical-table 
     "Std_drill-table"
     :columns     '(:Dr_size       :Dr_dia    :Std_tap)
     :columnNames '("Drill size"   "Diameter"  "Std Tap" )
     :types       '(:string          :length     :string)
     :units       '(   nil            :inch         nil )
     :contents std_dr_lst
)

(sd-create-display-table
     "Std_drill-table"
     :tableTitle "Std Drill Sizes"
     :logicalTable  "Std_drill-table"
     :columns     '(:Dr_size       :Dr_dia   :Std_tap )
     :applyColumns          '(:Dr_dia)
     :displayHeight 200
     :filterStatusLine       nil
     :selectionMode          :single-row 
     :applyAction            :default-tokens
)

(defun lhc-show-drill-table ()
  (sd-show-display-table "Std_drill-table"
                              :position '("TOP-MENU-TOOLBOX-TB"
                                                       :bottomleft  325 160)
  )
)

(defun lhc-hide-drill-table ()
  (sd-hide-display-table "Std_drill-table" :ignorePin t))

;; Calls functions "drill_hl" "bore_hl" & "punch_hl"

(sd-defdialog 'lhc_hl_drill
  :dialog-title "Drill Hole"
  :variables
  '((POINT_LIST)
   (A_PART 
            :value-type :part-incl-new
	      :modifies :contents 
	      :title "Part"
	      :prompt-text "Identify part to bore.")
    (A_WP   
            :value-type :wp 
	      :title "Workplane"
	      :prompt-text "Identify workplane.")
    (PNT_1  
            :value-type :point-3d-pick
            :title "Location"
            :toggle-type :invisible
            :prompt-text "Pick a point or press Back"
            :after-input (progn
                         (push-point pnt_1)
                         (sd-call-cmds (c_point pnt_1))))
    (TMP_NUM
            :initial-value 0)

    (NM_HLS
            :title "No. Hls"
            :value-type :display-only
            :initial-value 0
            :display-units :length) 

    (B_DPTH 
            :value-type :positive-number
            :title "Depth"
            :prompt-text "Enter drill depth")
    (DR_DIA 
            :value-type :positive-number
            :title "Diameter"
            :show-input-tool (lhc-show-drill-table)
            :hide-input-tool (lhc-hide-drill-table)  
            :prompt-text "Enter drill diameter"
            :after-input
             (setq Table_values (sd-read-logical-table-row
                                 "Std_drill-table"
                                 :pList `(:Dr_dia, dr_dia)
                                 :units  :internal
                             )
        )
 ;    (BACK :push-action (pop-point))

      :afterApplyBehavior   :close-if-not-pinned
    )
    ("-")

   (MACH_OP
            :initial-value 1
   )

    (PCH_THRU 
            :value-type :boolean
            :toggle-type :wide-toggle
            :initial-value nil
            :title "Thru Hole"
            :after-input
               (progn
                  (setq pch_thru t)
                  (setq pnt_pnt nil)
                  (setq flat_pnt nil)
                  (setq mach_op 3)
                  (sd-set-variable-status 'b_dpth :optional t) 
                )
    )

    (PNT_PNT 
            :value-type :boolean
            :toggle-type :wide-toggle
            :initial-value t
            :title "Std Drill Pnt"
            :after-input
               (progn
                  (setq pnt_pnt t)
                  (setq pch_thru nil)
                  (setq flat_pnt nil)
                  (setq mach_op 1)
                  (sd-set-variable-status 'b_dpth :enable t :optional nil) 
                )
    )
    (FLAT_PNT 
            :value-type :boolean
            :initial-value nil
            :toggle-type :wide-toggle
            :title "Flat bottom"
            :after-input
               (progn
                  (setq flat_pnt t)
                  (setq pch_thru nil)
                  (setq pnt_pnt nil)
                  (setq mach_op 2)
                  (sd-set-variable-status 'b_dpth :enable t :optional nil) 
                )
    )

  (BACK :push-action (pop-point))

 )
  :local-functions
    '((PUSH-POINT (a-new-point)
         (push a-new-point point_list)
         (setq tmp_num (+ tmp_num 1))
         (setq nm_hls (* tmp_num 25.4))
;          (display a-new-point)
     )
      (POP-POINT ()
         (pop point_list)
         (setq tmp_num (- tmp_num 1))
         (setq nm_hls (* tmp_num 25.4))
         (unless point_list
           (sd-set-variable-status 'back :enable nil)))

      (MAIN-ACTION ()
       (case mach_op
          (1 (dolist (pnt_1 point_list) 
             (drill_hl a_part pnt_1 b_dpth dr_dia)))
          (2 (dolist (pnt_1 point_list)
             (bore_hl a_part pnt_1 b_dpth dr_dia)))
          (3 (dolist (pnt_1 point_list)
             (punch_hl a_part pnt_1 dr_dia)))
       )
    ))

  :prompt-variable 'pnt_1
  :ok-action
     '(main-action))

