#|

 13-Nov-1999  This is a dialog to create a dowel pin at selected location.  
 
 14-Dec-1999  Added code for optional redrill.

 15-Dec-1999  Adding code for multiple locations.
              Functions without crashing, but shares wrong part.  Need to research
              partname/object functions. 

              Dowel is built and copied correctly, but need to call functions to
              punch and redrill the additional holes in multiple locations.

 16-Dec-1999  Builds and shares dowels correctly.  Machines additional locations.

|#

;; Last modified  : 16-Dec-1999
;; Category       : Parts
;; Author         : Bruce Fisher (bfisher@lhcarbide.com)
;; Company        : L.H. Carbide Corporation
;; Macro Purpose  : Create a dowel pin
;; Filename       : mk_dwl_d.lsp
;; SD Revision	: 7.11,7.51
;; Macro Revision	: 2.20
;; Platform       : Windows NT 4.0
;; Video Mode        :  Native
;; Monitor Resolution:  1280x1024

(in-package :LHC)
(use-package :OLI)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; Calls function "make_dwl"

(sd-defdialog 'lhc_mk_dwl
  :dialog-title "Dowel Pin"
  :variables
  '((POINT_LIST)
    (A_PART 
            :value-type :part-incl-new
	      :modifies :contents 
	      :title "Part"
	      :prompt-text "Identify parent part.")
    (A_WP   
            :value-type :wp 
	      :title "Workplane"
	      :prompt-text "Identify workplane.")
    (A_ASM   
            :value-type :assembly 
	      :modifies :contents 
	      :title "Assembly"
	      :prompt-text "Select Assembly.")
    (D_NAME   
            :value-type :string 
	      :title "Dowel Name"
            :initial-value "dwl_new"
	      :prompt-text "Enter dowel name.")
    (PNT_1  
            :value-type :point-3d-pick
            :title "Location"
            :prompt-text "Enter location for dowel."
            :after-input (progn
              (push-point pnt_1)
              (sd-call-cmds (c_point pnt_1)))
    )
    (PNT_2)  
    (D_DIA 
            :title "Diameter"
            :range (.125 .1875 .25 .3125 .375 .4375 .5 .625 .75 .875 1.0)
            :after-input
              (case D_DIA
                (.125 (sd-set-range 'D_LGTH '(.375 .5 .625 .75 .875 1.0 1.25 1.5 1.75 2.0)))
                (.1875 (sd-set-range 'D_LGTH '(.5 .625 .75 .875 1.0 1.25 1.5 1.75 2.0)))
                (.25 (sd-set-range 'D_LGTH '(.5 .625 .75 .875 1.0 1.25 1.5 1.75 2.0 2.25 2.5)))
                (.3125 (sd-set-range 'D_LGTH '(.5 .625 .75 .875 1.0 1.25 1.5 1.75 2.0 2.25 2.5 3.0)))
                (.375 (sd-set-range 'D_LGTH '(.5 .625 .75 .875 1.0 1.25 1.5 1.75 2.0 2.25 2.5 3.0)))
                (.4375 (sd-set-range 'D_LGTH '(1.0 1.25 1.5 1.75 2.0 2.5 3.0)))
                (.5 (sd-set-range 'D_LGTH '(.75 .875 1.0 1.25 1.5 1.75 2.0 2.25 2.5 3.0 3.5 4.0)))
                (.625 (sd-set-range 'D_LGTH '(1.0 1.25 1.5 1.75 2.0 2.25 2.5 3.0 3.5 4.0)))
                (.75 (sd-set-range 'D_LGTH '(2.0 2.5 3.0 3.5 4.0)))
                (.875 (sd-set-range 'D_LGTH '(2.0 3.0 4.0)))
                (1.0 (sd-set-range 'D_LGTH '(2.0 2.5 3.0 3.5 4.0)))
    ))

    (D_LGTH 
            :title "Length"
            :range (.375 .5 .625 .75 .875 1.0 1.25 1.5 1.75 2.0))
    (D_DPTH 
            :value-type :number
            :title "Dwl Depth"
            :initial-value 0
            :prompt-text "Enter distance to top of dowel"
     )

    (REDR_DPTH 
            :value-type :number
            :title "Redr Depth"
            :initial-value 0
            :prompt-text "Enter depth of Redrill"
     )

   (MACH_OP
            :initial-value 1
   )
    (INC_NUM   
            :value-type :integer
            :toggle-type :invisible
	      :initial-value 0
    )

    (NEW_PRT_NM
            :initial-value "New_copy"
    )     

    (NM_ADD)

    (TMP_SEL)

    (TMP_NM)

    (O_PRT)

    ("-")

      (Mk_redr 
          :value-type :boolean
          :toggle-type :wide-toggle
          :title "With Redrill"
          :initial-value nil
          :enable nil
          :optional nil
          :after-input
             (progn
                (setq mk_redr t)
                (setq no_redr nil)
                (setq mach_op 2)
                (sd-set-variable-status 'redr_dpth :enable t :optional t) 
              )
      )

      (No_redr 
          :value-type :boolean
          :toggle-type :wide-toggle
          :title "No Redrill"
          :initial-value t
          :after-input
             (progn
                (setq no_redr t)
                (setq mk_redr nil)
                (setq mach_op 1)
                (sd-set-variable-status 'redr_dpth :enable nil :optional nil) 
              )
       )

   (BACK :push-action (pop-point)))

  :local-functions

     '((PUSH-POINT (a-new-point)
         (push a-new-point point_list)
     )
      (POP-POINT ()
         (pop point_list)
         (unless point_list
           (sd-set-variable-status 'back :enable nil)))

       (DWL-MAKE ()
       (progn
       (case mach_op
          (1 (progn
             (punch_hl a_part pnt_1 (+ d_dia .0002)) 
             (make_dwl a_part pnt_1 d_dpth d_lgth (+ d_dia .0002) a_asm d_name))
             ) 
          (2 (progn
             (punch_hl a_part pnt_1 (+ d_dia .0002)) 
             (make_dwl a_part pnt_1 d_dpth d_lgth (+ d_dia .0002) a_asm d_name))
             (drill_hl a_part pnt_1 redr_dpth (+ d_dia .03125))
             )
           )
       ))

       (MAIN-ACTION ()
         (progn
         (dwl-make)
         (setq o_prt d_name)
         (setq tmp_nm (sd-inq-obj-pathname a_asm))
         (setq t2 (concatenate 'string tmp_nm "/" d_name))
         (setq tmp_sel (sd-pathname-to-obj t2))

         (pop point_list)
         (when point_list
         (progn
         (dolist (pnt_2 point_list)
         (multi-dwl pnt_1 pnt_2))

         (dolist (pnt_2 point_list)
         (dwl_hl_cp pnt_2))
         (current_part a_part)
          )
          )
       ))

       (DWL_HL_CP (p_2)
       (case mach_op
          (1 (punch_hl a_part p_2 (+ d_dia .0002)) 
              )
          (2 (progn
             (punch_hl a_part p_2 (+ d_dia .0002)) 
             (drill_hl a_part p_2 redr_dpth (+ d_dia .03125))
             )
           )
       ))

      (MULTI-DWL (pt_1 pt_2)
         (progn
         (setq inc_num (+ inc_num 1))
         (setq nm_add (sd-num-to-string inc_num))
         (setq new_prt_nm (concatenate 'string o_prt "." nm_add))
         (sd-call-cmds (create_multiple_pa 
                            :share
                            :source tmp_sel
                            :name new_prt_nm
                            :owner a_asm
                            :keep_attr :on
                            :translate :two_ptv pt_1 pt_2)
          ))
      ) 
  )

  :ok-action
  '(main-action))
